summaryrefslogtreecommitdiff
path: root/java/com/android/dialer/inject
diff options
context:
space:
mode:
Diffstat (limited to 'java/com/android/dialer/inject')
-rw-r--r--java/com/android/dialer/inject/ApplicationContext.java22
-rw-r--r--java/com/android/dialer/inject/ContextModule.java7
2 files changed, 26 insertions, 3 deletions
diff --git a/java/com/android/dialer/inject/ApplicationContext.java b/java/com/android/dialer/inject/ApplicationContext.java
new file mode 100644
index 000000000..913e36ef5
--- /dev/null
+++ b/java/com/android/dialer/inject/ApplicationContext.java
@@ -0,0 +1,22 @@
+/*
+ * Copyright (C) 2017 The Android Open Source Project
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License
+ */
+package com.android.dialer.inject;
+
+import javax.inject.Qualifier;
+
+/** Annotation for retrieving the application context. */
+@Qualifier
+public @interface ApplicationContext {}
diff --git a/java/com/android/dialer/inject/ContextModule.java b/java/com/android/dialer/inject/ContextModule.java
index aa83f0105..e3da08edc 100644
--- a/java/com/android/dialer/inject/ContextModule.java
+++ b/java/com/android/dialer/inject/ContextModule.java
@@ -22,17 +22,18 @@ import com.android.dialer.common.Assert;
import dagger.Module;
import dagger.Provides;
/** Provides the singleton context object. */
@Module
public final class ContextModule {
@NonNull private final Context context;
- public ContextModule(@NonNull Context context) {
- this.context = Assert.isNotNull(context);
+ public ContextModule(@NonNull Context appContext) {
+ this.context = Assert.isNotNull(appContext);
}
@Provides
+ @ApplicationContext
Context provideContext() {
return context;
}
@@ -22,17 +22,18 @@ import com.android.dialer.common.Assert;
import dagger.Module;
import dagger.Provides;
-/** Provides the singleton context object. */
+/** Provides the singleton application context object. */
public final class ContextModule {